const fetch = require("node-fetch");

class Bot {
  constructor(url) {
    this.webhookUrl = url;
  }
  post(data) {
    return fetch(this.webhookUrl, {
      method: "POST",
      headers: {
        "content-type": "application/json; charset=utf-8",
      },
      body: JSON.stringify(data),
    })
      .then((res) => res.json())
      .then((data) => {
        if (data.StatusMessage === "success") {
          console.info("发送成功");
          return data;
        } else {
          //   throw new Error(data);
          console.error("发送失败");
          return data;
        }
      })
      .catch((err) => {
        console.error("发送失败，发生错误！");
        throw err;
      });
  }
  sendText(text) {
    /**
     * @ 单个用户
     * <at user_id="ou_xxx">名字</at>
     * @ 所有人
     * <at user_id="all">所有人</at>
     */
    return this.post({
      msg_type: "text",
      content: {
        text,
      },
    });
  }
  sendRich(content) {
    /**
     * 富文本
     * title: 标题 [可选]
     * content 接受二维数组，每个数组代表一行消息
     * [{ tag: "text", "text": "hello" }]
     * 数组内容为内容对象，支持4种类型: text, a, at, img
     * text:
     *  text: 文本内容  [必填]
     *  un_escape: 是否解码 [可选]
     * a:
     *  text: 链接内容  [必填]
     *  href: 地址 [可选]
     * at:
     *  user_id: open_id，union_id或user_id [必填]
     *  user_name: 用户姓名 [可选]
     * img:
     *  image_key: 上传到飞书的文件 key [必填]
     */
    return this.post({
      msg_type: "post",
      content: {
        post: {
          zh_cn: content,
        },
      },
    });
  }
  sendCard(content) {
    console.log(content);
    return this.post({
      msg_type: "interactive",
      card: content,
    });
  }
  shareChat(chat_id) {
    return this.post({
      msg_type: "share_chat",
      content: {
        share_chat_id: chat_id,
      },
    });
  }
  shareUser(user_id) {
    return this.post({
      msg_type: "share_user",
      content: {
        user_id: user_id,
      },
    });
  }
  shareImage(file_key) {
    return this.post({
      msg_type: "image",
      content: {
        file_key: file_key,
      },
    });
  }
  shareAudio(file_key) {
    return this.post({
      msg_type: "audio",
      content: {
        file_key: file_key,
      },
    });
  }
  shareMedia(file_key) {
    return this.post({
      msg_type: "media",
      content: {
        file_key: file_key,
      },
    });
  }
  shareSticker(file_key) {
    return this.post({
      msg_type: "sticker",
      content: {
        file_key: file_key,
      },
    });
  }
}

module.exports = Bot;
